container_metro_poke

Function container_metro_poke 

pub fn container_metro_poke(container: &str) -> Option<String>
METRO_POKE as the named container actually has it, which is not always what the env file says: a container keeps the environment it was created with until it is recreated.