pub fn set_env_key( path: &Path, key: &str, value: &str, note: &str, ) -> Result<()>
Set key in a .env file, preserving comments and the order of what is already there. Appends with a note when the key is absent.
key